@@ -40,8 +40,8 @@
 # import jgtpy.JGTIDS as ids
 #from jgtdotenv import load_dotenv
 #import jgtdotenv
-
-from jgtpy.JGTCore import __version__,json2dict,jsonfile2prop,json2prop,jsonfile2dict,d2p
+from jgtpy.jgtetl import svc_offset_dt_by_tf,offsetdt
+from jgtpy.JGTCore import __version__,json2dict,jsonfile2prop,json2prop,jsonfile2dict,d2p,fixdtindf,offsetdt
 from jgtpy.JGTConfig import getenv,setreal,setdemo,env
 
 from jgtpy.JGTPDS import mk_fn,mk_fullpath,getSubscribed,getPH,getPHByRange,tryConnect
